elephant.spike\_train\_synchrony.Synchrotool
============================================

.. currentmodule:: elephant.spike_train_synchrony

.. autoclass:: Synchrotool
   :members:
   :inherited-members:
   :special-members: __call__, __getitem__, __setitem__

   

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Synchrotool.__init__
      ~Synchrotool.annotate_synchrofacts
      ~Synchrotool.delete_synchrofacts
      ~Synchrotool.pdf
   
   

   
   
   